==> gnue-forms_0.5.4.orig.tar.gz: gnue-forms-0.5.4/src/uidrivers/win32/widgets/label.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
# FILE:
# win32/widgets/label.py
#
# DESCRIPTION:
# A PyWin32 based user interface driver for GNUe forms.
#
# NOTES:
#

import win32gui, win32con

from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
from gnue.forms.uidrivers.win32.common import *

#
# UILabel
#
# Widget set specific function that creates a single instance of a label
#
class UILabel(UIHelper):
  alignmentStyle = { 'left'  : win32con.SS_LEFT | win32con.WS_CHILD,
                     'center': win32con.SS_CENTER | win32con.WS_CHILD,
                     'right' : win32con.SS_RIGHT | win32con.WS_CHILD
                     }

  def _createWidget(self, event, spacer):
    object = event.object
    if self.itemWidth == -1:
      self.itemWidth = len(str(object.text))*event.widgetWidth
      self.itemHeight = len(str(object.text))*event.widgetHeight
    style = self.alignmentStyle[object.alignment]
    styleEx = 0
    newWidget = Win32Window(self._uiDriver, styleEx, 'STATIC', textEncode(object.text), style,
                        object.Char__x*event.widgetWidth,
                        (object.Char__y+spacer+(spacer*object._gap))*event.widgetHeight, 
                        self.itemWidth,
                        self.itemHeight,
                        event.container)
    return newWidget


configuration = {
    'baseClass'  : UILabel,
    'provides'   : 'GFLabel',
    'container'  : 0,
    }

==> gnue-forms_0.5.11.orig.tar.gz: gnue-forms-0.5.11/src/uidrivers/win32/widgets/label.py <==
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
# $Id: label.py 6851 2005-01-03 20:59:28Z jcater $
#
# DESCRIPTION:
# A PyWin32 based user interface driver for GNUe forms.
#
# NOTES:
#

import win32gui, win32con

from gnue.forms.uidrivers.win32.widgets._base import UIHelper, Win32Window
from gnue.forms.uidrivers.win32.common import *

#
# UILabel
#
# Widget set specific function that creates a single instance of a label
#
class UILabel(UIHelper):
  alignmentStyle = {'left'  : win32con.SS_LEFT,
                    'center': win32con.SS_CENTER,
                    'right' : win32con.SS_RIGHT}

  def _createWidget(self, event, spacer):
    object = event.object
    if self.itemWidth == -1:
      self.itemWidth = len(str(textEncode(object.text)))*event.widgetWidth
    if self.itemHeight == -1:
      self.itemHeight = event.widgetHeight
    
    style = self.alignmentStyle[object.alignment] | win32con.WS_CHILD #| win32con.SS_SUNKEN
    styleEx = 0
    newWidget = Win32Window(self._uiDriver, styleEx, 'STATIC', textEncode(object.text), style,
                        self.itemX,
    # Make sure the baseline of labels and widgets are the same
                        self.itemY + 3,
                        self.itemWidth,
                        self.itemHeight,
                        event.container)
    return newWidget


configuration = {
    'baseClass'  : UILabel,
    'provides'   : 'GFLabel',
    'container'  : 0,
    }
